==> 0.0.1%2B1.tar.gz: lib/models/IR5Etab.dart <==
import 'package:json_annotation/json_annotation.dart';

import 'IR5Address.dart' show IR5Address;

part 'IR5Etab.g.dart';

// --------------------------------------------------------------------------------
enum SrvcState { SvcUndefined, SvcOpenEmpty, SvcOpen, SvcClosing, SvcClosed }
const Map<int, SrvcState> SrvcStates = {
  0: SrvcState.SvcUndefined,
  1: SrvcState.SvcOpenEmpty,
  2: SrvcState.SvcOpen,
  3: SrvcState.SvcClosing,
  4: SrvcState.SvcClosed,
};
int SrvcStateToJson(SrvcState f) {
  return SrvcStates.entries.firstWhere((element) => element.value == f).key;
}

// --------------------------------------------------------------------------------
enum PayRounding { ExactPay, RoundTo5Cents, dotBERounding, dotBEOnlyCash }
const Map<int, PayRounding> PayRoundings = {
  0: PayRounding.ExactPay,
  1: PayRounding.RoundTo5Cents,
  2: PayRounding.dotBERounding,
  3: PayRounding.dotBEOnlyCash,
};
int PayRoundingToJson(PayRounding f) {
  return PayRoundings.entries.firstWhere((element) => element.value == f).key;
}
// --------------------------------------------------------------------------------

/** Etab aka Restaurant */
@JsonSerializable(explicitToJson: true)
class IR5Etab {
  const IR5Etab({
    required this.FDMMode,
    required this.FDMInfo,
    required this.FDMVerInfo,
    required this.FDMApprovalNumber,
    required this.CMAXNum,
    required this.Nom,
    required this.CompanyName,
    required this.HeadOffice,
    required this.Address,
    required this.TVA,
    required this.SIRET,
    required this.DEV0,
    required this.DateService,
    required this.NoService,
    required this.NomService,
    required this.ServiceStatus,
    required this.ServiceInfo,
    required this.ModeTVA,
    required this.TauxTVA1,
    required this.TauxTVA2,
    required this.TauxTVA3,
    required this.PayRounding,
    required this.Flags_Etab,
    required this.Flags_Station,
    required this.Flags_Staff,
    required this.Flags_Caisse,
    required this.Flags_Cloture,
    required this.Flags_Modules,
    required this.Flags_Members,
    required this.Flags_Stock,
    required this.AddLogo,
    required this.reg,
  });

  factory IR5Etab.fromJson(Map<String, dynamic>? json) => _$IR5EtabFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5EtabToJson(this);

  /** Fiscal Data Module
    * X:NoFDMMode
    * D:DebugMode (internal Restomax mode)
    * b:BelgiumMode Demo
    * B:BelgiumMode
    */
  @JsonKey(defaultValue: '')
  final String FDMMode;
  @JsonKey(defaultValue: '')
  final String FDMInfo;
  @JsonKey(defaultValue: '')
  final String FDMVerInfo;
  @JsonKey(defaultValue: '')
  final String FDMApprovalNumber;
  /** Internal Restomax Unique Customer Number */
  @JsonKey(defaultValue: '')
  final String CMAXNum;
  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: '')
  final String CompanyName;
  @JsonKey(defaultValue: '')
  final String HeadOffice;
  final IR5Address Address;
  @JsonKey(defaultValue: '')
  final String TVA;
  @JsonKey(defaultValue: '')
  final String SIRET;
  /** Currency Id ex:EUR */
  @JsonKey(defaultValue: '')
  final String DEV0;
  /** Service Date */
  @JsonKey(defaultValue: '')
  final String DateService;
  /** Service Number */
  @JsonKey(defaultValue: 0)
  final num NoService;
  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomService;
  /** Service Status
    *     csNoSrvc = 0
    *     csSrvcOuvertNonUtilise = 1
    *     csSrvcOuvertUtilise = 2
    *     csSrvcClotureEnCours = 3
    *     csSrvcCloture = 4
    */
  @JsonKey(defaultValue: 0)
  final int /* Number | SrvcState */ ServiceStatus;
  @JsonKey(defaultValue: '')
  final String ServiceInfo;
  /** VAT Mode
    * vatModeRestomax,
    * vatModePOS
    */
  @JsonKey(defaultValue: '')
  final String ModeTVA;
  /** VAT Rate 1 = 6% */
  @JsonKey(defaultValue: 6)
  final num TauxTVA1;
  /** VAT Rate 2 = 12% */
  @JsonKey(defaultValue: 12)
  final num TauxTVA2;
  /** VAT Rate 3 = 21% */
  @JsonKey(defaultValue: 21)
  final num TauxTVA3;
  @JsonKey(defaultValue: 0)
  final int /* Number | PayRounding */ PayRounding;
  /** Etab Flags
    *   Bit 10 : LockPrice
    *   Bit 11 : ForceRecalc
    *   Bit 12 : TaxExNoRecalc
    *   Bit 15 : RoundTo05Cents
    *   Bit 16 : DotBERounding
    *   Bit 17 : DotBEOnlyCash
    *   Bit 20 : PlanSalleRuntimeDesign
    *   Bit 21 : RestomaxLongClick
    *   Bit 30 : AlwaysShowQtOnTicket
    *   Bit 40 : OLAPExportHistoDeleteAllowed
    *   Bit 41 : OLAPArchiveHistoDeleteAllowed
    *   Bit 46 : ShowAvgs
    *   Bit 47 : ShowCvts
    *   Bit 48 : ShowQty
    *   Bit 49 : ShowPercent
    *   Bit 50 : ShowTHOUSANDSEPARATOR
    *   Bit 51 : ShowKILO
    *   Bit 56 : TicketNumByRoute
    *   Bit 57 : TicketNumByPtr
    *   Bit 58 : TicketNumCdes
    *   Bit 59 : TicketNumSeqs
    *   Bit 60 : RptNumXZ
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Etab;
  /** Etab StationCtrl Flags
    *   Bit 00 : Reserved
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Station;
  /** Etab StaffCtrl Flags
    *   Bit 10 : fStaffNISSCtrl
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Staff;
  /** Etab Pointage Flags
    *   Bit 00 : ForceTariffNormal
    *   Bit 01 : ForceTariffHappyHour
    *   Bit 02 : AutoHappyHour
    *   Bit 03 : ShortHold
    *   Bit 04 : LogOffAfterShortHold
    *   Bit 05 : LongHold
    *   Bit 06 : LogOffAfterLongHold
    *   Bit 07 : HoldTakeStock
    *   Bit 08 : LogTblHold
    *   Bit 10 : DiscountLimited
    *   Bit 11 : TableBloqueGarcon
    *   Bit 12 : AdditionBloqueGarcon
    *   Bit 13 : CashBloqueGarcon
    *   Bit 16 : ShowErrLine
    *   Bit 17 : LimitModeInOut
    *   Bit 18 : KeepErrLine
    *   Bit 19 : ModeTraining
    *   Bit 20 : AuthJustification
    *   Bit 21 : AuthByAllowed
    *   Bit 22 : NoCumulSalesRefund
    *   Bit 23 : FullTicketMsg
    *   Bit 26 : DoNumSeq
    *   Bit 27 : NumSeqRestart
    *   Bit 29 : DontNumSales
    *   Bit 30 : NumSalesAtOuverture
    *   Bit 31 : NumSalesAtAddition
    *   Bit 32 : NumSalesAtCloture
    *   Bit 33 : NumSalesRestart
    *   Bit 36 : BISOrderByCategorie
    *   Bit 37 : BISNoExternalPLUs
    *   Bit 38 : BISShowZero
    *   Bit 39 : BISAutoReload
    *   Bit 40 : BISNoColor
    *   Bit 43 : LancerBeforeEnCaisse
    *   Bit 44 : CashDrawerMsg
    *   Bit 45 : TicketSimple
    *   Bit 46 : OnlyOneTicketSimple
    *   Bit 47 : LogTicketSimple
    *   Bit 48 : NoAddition
    *   Bit 49 : NoAdditionIffInvoice
    *   Bit 50 : LancerBeforeAddition
    *   Bit 51 : AdditionBrute
    *   Bit 52 : AdditionBySsAdd
    *   Bit 53 : ShowForfaitOnAdd
    *   Bit 54 : ShowDetailsMenuOnAdd
    *   Bit 55 : AdditionByCateg
    *   Bit 58 : AdditionDotBE
    *   Bit 59 : AdditionGlobale
    *   Bit 60 : AdditionBySeq
    *   Bit 61 : AdditionBySep
    *   Bit 62 : LogAdditionDupl
    *   Bit 63 : CheckVATSalesRefund
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Caisse;
  /** Etab Cloture Flags
    *   Bit 00 : OuvSrvcAuto
    *   Bit 01 : OuvSrvcForceDate
    *   Bit 06 : OpenService_FDMStartForced
    *   Bit 10 : ClotureAuto
    *   Bit 11 : ClotureAutoDayZero
    *   Bit 13 : ClotureAutoWithOpenTbls
    *   Bit 14 : ClotureAutoTblsBlanco
    *   Bit 15 : ClotureAutoKeepTbls
    *   Bit 16 : ClotureAutoTbls
    *   Bit 17 : ClotureKeepTbls
    *   Bit 18 : ClotureWithOpenTbls
    *   Bit 19 : ClotureTblsBlanco
    *   Bit 20 : ClotureWithOpenStaffs
    *   Bit 21 : DeleteHisto
    *   Bit 22 : ArchiveHisto
    *   Bit 23 : ClotureTbls
    *   Bit 24 : Archive2Cloud
    *   Bit 25 : ConsolideBarControl
    *   Bit 26 : KeepHistoDays
    *   Bit 28 : ClotureAutoPrintRptZ
    *   Bit 29 : ClotureAutoMailRptZ
    *   Bit 33 : CloturePrintRptZ
    *   Bit 34 : ClotureMailRptZ
    *   Bit 36 : ClotureForceShutdown
    *   Bit 37 : ClotureShowShutdown
    *   Bit 38 : AllwaysShowCloture
    *   Bit 39 : RAZPlanSalle
    *   Bit 40 : KeepNoTable
    *   Bit 47 : RptOuvStaff
    *   Bit 50 : StaffCloture
    *   Bit 51 : RptClotStaff
    *   Bit 54 : FullDailyBackup2Cloud
    *   Bit 55 : FullMonthlyBackup2Cloud
    *   Bit 56 : OnlyDataDailyBackup2Cloud
    *   Bit 57 : OnlyDataMonthlyBackup2Cloud
    *   Bit 59 : SaveNumZTot
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Cloture;
  /** Etab Modules Flags
    *   Bit 00 : Member
    *   Bit 07 : ModuleStock
    *   Bit 12 : RptClockInOut
    *   Bit 16 : PayJetonModule
    *   Bit 21 : FreeVoucherModule
    *   Bit 27 : HotelLnk
    *   Bit 30 : HotSpotCodes
    *   Bit 31 : PayHotelHTNG
    *   Bit 32 : GantnerReader
    *   Bit 33 : FingerPrintReader
    *   Bit 34 : SmartCardReader
    *   Bit 35 : RestoPass
    *   Bit 36 : PayCortess
    *   Bit 38 : HappyHour
    *   Bit 39 : Balance
    *   Bit 40 : Evenement
    *   Bit 41 : Reservation
    *   Bit 42 : BadgeReader
    *   Bit 43 : BarCodeReader
    *   Bit 44 : CustomerDisplay
    *   Bit 45 : AccLink
    *   Bit 46 : Telemax
    *   Bit 47 : SEPAFile
    *   Bit 49 : ExternalPLUsLnk
    *   Bit 50 : ModuleRptParGarcon
    *   Bit 51 : DontSignClockIN
    *   Bit 52 : NeedClockIN
    *   Bit 53 : ModulePrestation
    *   Bit 54 : ClockINout
    *   Bit 55 : AutoClockINout
    *   Bit 56 : BarControlLog2File
    *   Bit 57 : BarControl
    *   Bit 58 : BarControlByStation
    *   Bit 59 : BarControlIgNoreNegatif
    *   Bit 60 : BankTerminals
    *   Bit 63 : CashMachines
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Modules;
  /** Etab Stock Flags
    *   Bit 00 : CptesClient
    *   Bit 01 : AutoPrintNewMember
    *   Bit 02 : FactDNeedVATNr
    *   Bit 04 : MemberTariff
    *   Bit 05 : DirectDiscount
    *   Bit 06 : GlobalDiscount
    *   Bit 10 : SoloCloture
    *   Bit 12 : MonthlyClotureWithReport
    *   Bit 14 : MonthlyClotureWithRAZ
    *   Bit 19 : MonthlyFact
    *   Bit 20 : FactDirect
    *   Bit 21 : FactDirectAllowTicket
    *   Bit 22 : FactDirectAllowPrint
    *   Bit 23 : FactDirectAllowMail
    *   Bit 24 : FactDirectAllowNoDetails
    *   Bit 27 : FactDeferred
    *   Bit 28 : FactDDLog
    *   Bit 29 : LogRePrintInvTicket
    *   Bit 30 : SoloClotureAutoAfterPtr
    *   Bit 31 : SoloClotureAutoAfterPtrAsk
    *   Bit 35 : SoloClotureAutoAfterRecharge
    *   Bit 36 : SoloClotureAutoAfterRechargeRAZ
    *   Bit 40 : ForceSaveHisto
    *   Bit 43 : NoFidelityPointsIfDiscount
    *   Bit 51 : AutoFreeVoucher
    *   Bit 52 : UseFreeVoucher
    *   Bit 53 : FreeVoucherCheckTotalTbl
    *   Bit 54 : FreeVoucherCheckClient
    *   Bit 55 : MakeFreeVoucherAuto
    *   Bit 56 : DoNotPrintFreeVoucherAuto
    *   Bit 57 : FreeVoucherTruncToTotalTbl
    *   Bit 58 : FreeVoucherCheckCMAXNum
    *   Bit 60 : RptShowTVAVentil
    *   Bit 61 : FullNameAsPrenomNom
    *   Bit 62 : FullNameAsOnlyNom
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Members;
  /** Etab Stock Flags
    *   Bit 20 : HasBlocageAuto
    *   Bit 21 : PassThroughBlocageManual
    *   Bit 22 : PassThroughBlocageAuto
    *   Bit 23 : LogBlocageManual
    *   Bit 24 : LogBlocageAuto
    *   Bit 40 : StockManagement
    *   Bit 41 : KeepVente
    *   Bit 42 : KeepAchat
    *   Bit 51 : AskCostPrice
    *   Bit 52 : AskAchatDesc
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Stock;
  /** Logo to be printed on Addition Ticket */
  @JsonKey(defaultValue: 0)
  final num AddLogo;
  /** Registry values */
  @JsonKey(defaultValue: {})
  final dynamic reg;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5Etab.dart <==
import 'package:json_annotation/json_annotation.dart';

import 'IR5Address.dart' show IR5Address;

part 'IR5Etab.g.dart';

// --------------------------------------------------------------------------------
enum SrvcState { SvcUndefined, SvcOpenEmpty, SvcOpen, SvcClosing, SvcClosed }
const Map<int, SrvcState> SrvcStates = {
  0: SrvcState.SvcUndefined,
  1: SrvcState.SvcOpenEmpty,
  2: SrvcState.SvcOpen,
  3: SrvcState.SvcClosing,
  4: SrvcState.SvcClosed,
};
int SrvcStateToJson(SrvcState f) {
  return SrvcStates.entries.firstWhere((element) => element.value == f).key;
}

// --------------------------------------------------------------------------------
enum PayRounding { ExactPay, RoundTo5Cents, dotBERounding, dotBEOnlyCash }
const Map<int, PayRounding> PayRoundings = {
  0: PayRounding.ExactPay,
  1: PayRounding.RoundTo5Cents,
  2: PayRounding.dotBERounding,
  3: PayRounding.dotBEOnlyCash,
};
int PayRoundingToJson(PayRounding f) {
  return PayRoundings.entries.firstWhere((element) => element.value == f).key;
}
// --------------------------------------------------------------------------------

/** Etab aka Restaurant */
@JsonSerializable(explicitToJson: true)
class IR5Etab {
  const IR5Etab({
    required this.FDMMode,
    required this.FDMInfo,
    required this.FDMVerInfo,
    required this.FDMApprovalNumber,
    required this.CMAXNum,
    required this.Nom,
    required this.CompanyName,
    required this.HeadOffice,
    required this.Address,
    required this.TVA,
    required this.SIRET,
    required this.DEV0,
    required this.DateService,
    required this.NoService,
    required this.NomService,
    required this.ServiceStatus,
    required this.ServiceInfo,
    required this.ModeTVA,
    required this.TauxTVA1,
    required this.TauxTVA2,
    required this.TauxTVA3,
    required this.PayRounding,
    required this.Flags_Etab,
    required this.Flags_Station,
    required this.Flags_Staff,
    required this.Flags_Caisse,
    required this.Flags_Cloture,
    required this.Flags_Modules,
    required this.Flags_Members,
    required this.Flags_Stock,
    required this.AddLogo,
    required this.reg,
  });

  factory IR5Etab.fromJson(Map<String, dynamic>? json) =>
      _$IR5EtabFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5EtabToJson(this);

  /** Fiscal Data Module
    * X:NoFDMMode
    * D:DebugMode (internal Restomax mode)
    * b:BelgiumMode Demo
    * B:BelgiumMode
    */
  @JsonKey(defaultValue: '')
  final String FDMMode;
  @JsonKey(defaultValue: '')
  final String FDMInfo;
  @JsonKey(defaultValue: '')
  final String FDMVerInfo;
  @JsonKey(defaultValue: '')
  final String FDMApprovalNumber;
  /** Internal Restomax Unique Customer Number */
  @JsonKey(defaultValue: '')
  final String CMAXNum;
  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: '')
  final String CompanyName;
  @JsonKey(defaultValue: '')
  final String HeadOffice;
  final IR5Address Address;
  @JsonKey(defaultValue: '')
  final String TVA;
  @JsonKey(defaultValue: '')
  final String SIRET;
  /** Currency Id ex:EUR */
  @JsonKey(defaultValue: '')
  final String DEV0;
  /** Service Date */
  @JsonKey(defaultValue: '')
  final String DateService;
  /** Service Number */
  @JsonKey(defaultValue: 0)
  final num NoService;
  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomService;
  /** Service Status
    *     csNoSrvc = 0
    *     csSrvcOuvertNonUtilise = 1
    *     csSrvcOuvertUtilise = 2
    *     csSrvcClotureEnCours = 3
    *     csSrvcCloture = 4
    */
  @JsonKey(defaultValue: 0)
  final int /* Number | SrvcState */ ServiceStatus;
  @JsonKey(defaultValue: '')
  final String ServiceInfo;
  /** VAT Mode
    * vatModeRestomax,
    * vatModePOS
    */
  @JsonKey(defaultValue: '')
  final String ModeTVA;
  /** VAT Rate 1 = 6% */
  @JsonKey(defaultValue: 6)
  final num TauxTVA1;
  /** VAT Rate 2 = 12% */
  @JsonKey(defaultValue: 12)
  final num TauxTVA2;
  /** VAT Rate 3 = 21% */
  @JsonKey(defaultValue: 21)
  final num TauxTVA3;
  @JsonKey(defaultValue: 0)
  final int /* Number | PayRounding */ PayRounding;
  /** Etab Flags
    *   Bit 10 : LockPrice
    *   Bit 11 : ForceRecalc
    *   Bit 12 : TaxExNoRecalc
    *   Bit 15 : RoundTo05Cents
    *   Bit 16 : DotBERounding
    *   Bit 17 : DotBEOnlyCash
    *   Bit 20 : PlanSalleRuntimeDesign
    *   Bit 21 : RestomaxLongClick
    *   Bit 30 : AlwaysShowQtOnTicket
    *   Bit 40 : OLAPExportHistoDeleteAllowed
    *   Bit 41 : OLAPArchiveHistoDeleteAllowed
    *   Bit 46 : ShowAvgs
    *   Bit 47 : ShowCvts
    *   Bit 48 : ShowQty
    *   Bit 49 : ShowPercent
    *   Bit 50 : ShowTHOUSANDSEPARATOR
    *   Bit 51 : ShowKILO
    *   Bit 56 : TicketNumByRoute
    *   Bit 57 : TicketNumByPtr
    *   Bit 58 : TicketNumCdes
    *   Bit 59 : TicketNumSeqs
    *   Bit 60 : RptNumXZ
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Etab;
  /** Etab StationCtrl Flags
    *   Bit 00 : Reserved
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Station;
  /** Etab StaffCtrl Flags
    *   Bit 10 : fStaffNISSCtrl
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Staff;
  /** Etab Pointage Flags
    *   Bit 00 : ForceTariffNormal
    *   Bit 01 : ForceTariffHappyHour
    *   Bit 02 : AutoHappyHour
    *   Bit 03 : ShortHold
    *   Bit 04 : LogOffAfterShortHold
    *   Bit 05 : LongHold
    *   Bit 06 : LogOffAfterLongHold
    *   Bit 07 : HoldTakeStock
    *   Bit 08 : LogTblHold
    *   Bit 10 : DiscountLimited
    *   Bit 11 : TableBloqueGarcon
    *   Bit 12 : AdditionBloqueGarcon
    *   Bit 13 : CashBloqueGarcon
    *   Bit 16 : ShowErrLine
    *   Bit 17 : LimitModeInOut
    *   Bit 18 : KeepErrLine
    *   Bit 19 : ModeTraining
    *   Bit 20 : AuthJustification
    *   Bit 21 : AuthByAllowed
    *   Bit 22 : NoCumulSalesRefund
    *   Bit 23 : FullTicketMsg
    *   Bit 26 : DoNumSeq
    *   Bit 27 : NumSeqRestart
    *   Bit 29 : DontNumSales
    *   Bit 30 : NumSalesAtOuverture
    *   Bit 31 : NumSalesAtAddition
    *   Bit 32 : NumSalesAtCloture
    *   Bit 33 : NumSalesRestart
    *   Bit 36 : BISOrderByCategorie
    *   Bit 37 : BISNoExternalPLUs
    *   Bit 38 : BISShowZero
    *   Bit 39 : BISAutoReload
    *   Bit 40 : BISNoColor
    *   Bit 43 : LancerBeforeEnCaisse
    *   Bit 44 : CashDrawerMsg
    *   Bit 45 : TicketSimple
    *   Bit 46 : OnlyOneTicketSimple
    *   Bit 47 : LogTicketSimple
    *   Bit 48 : NoAddition
    *   Bit 49 : NoAdditionIffInvoice
    *   Bit 50 : LancerBeforeAddition
    *   Bit 51 : AdditionBrute
    *   Bit 52 : AdditionBySsAdd
    *   Bit 53 : ShowForfaitOnAdd
    *   Bit 54 : ShowDetailsMenuOnAdd
    *   Bit 55 : AdditionByCateg
    *   Bit 58 : AdditionDotBE
    *   Bit 59 : AdditionGlobale
    *   Bit 60 : AdditionBySeq
    *   Bit 61 : AdditionBySep
    *   Bit 62 : LogAdditionDupl
    *   Bit 63 : CheckVATSalesRefund
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Caisse;
  /** Etab Cloture Flags
    *   Bit 00 : OuvSrvcAuto
    *   Bit 01 : OuvSrvcForceDate
    *   Bit 06 : OpenService_FDMStartForced
    *   Bit 10 : ClotureAuto
    *   Bit 11 : ClotureAutoDayZero
    *   Bit 13 : ClotureAutoWithOpenTbls
    *   Bit 14 : ClotureAutoTblsBlanco
    *   Bit 15 : ClotureAutoKeepTbls
    *   Bit 16 : ClotureAutoTbls
    *   Bit 17 : ClotureKeepTbls
    *   Bit 18 : ClotureWithOpenTbls
    *   Bit 19 : ClotureTblsBlanco
    *   Bit 20 : ClotureWithOpenStaffs
    *   Bit 21 : DeleteHisto
    *   Bit 22 : ArchiveHisto
    *   Bit 23 : ClotureTbls
    *   Bit 24 : Archive2Cloud
    *   Bit 25 : ConsolideBarControl
    *   Bit 26 : KeepHistoDays
    *   Bit 28 : ClotureAutoPrintRptZ
    *   Bit 29 : ClotureAutoMailRptZ
    *   Bit 33 : CloturePrintRptZ
    *   Bit 34 : ClotureMailRptZ
    *   Bit 36 : ClotureForceShutdown
    *   Bit 37 : ClotureShowShutdown
    *   Bit 38 : AllwaysShowCloture
    *   Bit 39 : RAZPlanSalle
    *   Bit 40 : KeepNoTable
    *   Bit 47 : RptOuvStaff
    *   Bit 50 : StaffCloture
    *   Bit 51 : RptClotStaff
    *   Bit 54 : FullDailyBackup2Cloud
    *   Bit 55 : FullMonthlyBackup2Cloud
    *   Bit 56 : OnlyDataDailyBackup2Cloud
    *   Bit 57 : OnlyDataMonthlyBackup2Cloud
    *   Bit 59 : SaveNumZTot
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Cloture;
  /** Etab Modules Flags
    *   Bit 00 : Member
    *   Bit 07 : ModuleStock
    *   Bit 12 : RptClockInOut
    *   Bit 16 : PayJetonModule
    *   Bit 21 : FreeVoucherModule
    *   Bit 27 : HotelLnk
    *   Bit 30 : HotSpotCodes
    *   Bit 31 : PayHotelHTNG
    *   Bit 32 : GantnerReader
    *   Bit 33 : FingerPrintReader
    *   Bit 34 : SmartCardReader
    *   Bit 35 : RestoPass
    *   Bit 36 : PayCortess
    *   Bit 38 : HappyHour
    *   Bit 39 : Balance
    *   Bit 40 : Evenement
    *   Bit 41 : Reservation
    *   Bit 42 : BadgeReader
    *   Bit 43 : BarCodeReader
    *   Bit 44 : CustomerDisplay
    *   Bit 45 : AccLink
    *   Bit 46 : Telemax
    *   Bit 47 : SEPAFile
    *   Bit 49 : ExternalPLUsLnk
    *   Bit 50 : ModuleRptParGarcon
    *   Bit 51 : DontSignClockIN
    *   Bit 52 : NeedClockIN
    *   Bit 53 : ModulePrestation
    *   Bit 54 : ClockINout
    *   Bit 55 : AutoClockINout
    *   Bit 56 : BarControlLog2File
    *   Bit 57 : BarControl
    *   Bit 58 : BarControlByStation
    *   Bit 59 : BarControlIgNoreNegatif
    *   Bit 60 : BankTerminals
    *   Bit 63 : CashMachines
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Modules;
  /** Etab Stock Flags
    *   Bit 00 : CptesClient
    *   Bit 01 : AutoPrintNewMember
    *   Bit 02 : FactDNeedVATNr
    *   Bit 04 : MemberTariff
    *   Bit 05 : DirectDiscount
    *   Bit 06 : GlobalDiscount
    *   Bit 10 : SoloCloture
    *   Bit 12 : MonthlyClotureWithReport
    *   Bit 14 : MonthlyClotureWithRAZ
    *   Bit 19 : MonthlyFact
    *   Bit 20 : FactDirect
    *   Bit 21 : FactDirectAllowTicket
    *   Bit 22 : FactDirectAllowPrint
    *   Bit 23 : FactDirectAllowMail
    *   Bit 24 : FactDirectAllowNoDetails
    *   Bit 27 : FactDeferred
    *   Bit 28 : FactDDLog
    *   Bit 29 : LogRePrintInvTicket
    *   Bit 30 : SoloClotureAutoAfterPtr
    *   Bit 31 : SoloClotureAutoAfterPtrAsk
    *   Bit 35 : SoloClotureAutoAfterRecharge
    *   Bit 36 : SoloClotureAutoAfterRechargeRAZ
    *   Bit 40 : ForceSaveHisto
    *   Bit 43 : NoFidelityPointsIfDiscount
    *   Bit 51 : AutoFreeVoucher
    *   Bit 52 : UseFreeVoucher
    *   Bit 53 : FreeVoucherCheckTotalTbl
    *   Bit 54 : FreeVoucherCheckClient
    *   Bit 55 : MakeFreeVoucherAuto
    *   Bit 56 : DoNotPrintFreeVoucherAuto
    *   Bit 57 : FreeVoucherTruncToTotalTbl
    *   Bit 58 : FreeVoucherCheckCMAXNum
    *   Bit 60 : RptShowTVAVentil
    *   Bit 61 : FullNameAsPrenomNom
    *   Bit 62 : FullNameAsOnlyNom
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Members;
  /** Etab Stock Flags
    *   Bit 20 : HasBlocageAuto
    *   Bit 21 : PassThroughBlocageManual
    *   Bit 22 : PassThroughBlocageAuto
    *   Bit 23 : LogBlocageManual
    *   Bit 24 : LogBlocageAuto
    *   Bit 40 : StockManagement
    *   Bit 41 : KeepVente
    *   Bit 42 : KeepAchat
    *   Bit 51 : AskCostPrice
    *   Bit 52 : AskAchatDesc
    */
  @JsonKey(defaultValue: 0)
  final num Flags_Stock;
  /** Logo to be printed on Addition Ticket */
  @JsonKey(defaultValue: 0)
  final num AddLogo;
  /** Registry values */
  @JsonKey(defaultValue: {})
  final dynamic reg;
}
